@@ -1,5 +1,48 @@
 context("map_layers")
 
+test_that("layerId includes all layers", {
+
+	# testthat::skip_on_travis()
+	# testthat::skip_on_cran()
+	# testthat::skip()
+	#
+	# layers <- c(
+	# 	"arc"
+	# 	, "bitmap"
+	# 	, "column"
+	# 	, "geojson"
+	# 	, "greatcircle"
+	# 	, "grid"
+	# 	, "heatmap"
+	# 	, "hexagon"
+	# 	, "line"
+	# 	, "mesh"
+	# 	, "path"
+	# 	, "pointcloud"
+	# 	, "polygon"
+	# 	, "scatterplot"
+	# 	, "screengrid"
+	# 	, "text"
+	# 	, "title"
+	# 	, "trips"
+	# )
+	#
+	# # expect_equal( layers, mapdeck:::mapdeck_layers() )
+	#
+	# f <- list.files(path = system.file("./R", package = "mapdeck") )
+	# f <- f[ grepl("map_layer_*", f) ]
+	# f <- gsub("map_layer_", "", f)
+	# f <- gsub("\\.R","",f)
+	# f <- sort( f )
+	# f <- setdiff(f, c("parameter_checks","sf"))
+	#
+	# expect_equal( f, sort( layers ) )
+	#
+	# res <- sapply( layers, function(x) { mapdeck:::layerId( layer_id = "test", layer = x) })
+	# expect_equal( layers, names( res ) )
+
+})
+
 
 # test_that("layer_ids required", {
 #
